Index: CONFIG/UNIFORM/v6/LMDZOR_v6.2/compile_lmdzor.sh
===================================================================
--- CONFIG/UNIFORM/v7/ICOLMDZOR_v7/compile_icolmdzor.sh	(revision 4409)
+++ CONFIG/UNIFORM/v6/LMDZOR_v6.2/compile_lmdzor.sh	(revision 4411)
@@ -11,5 +11,4 @@
 modipsl=$submitdir/../..
 arch_path=$submitdir/ARCH 
-export ROOT=$modipsl/modeles/DYNAMICO
 
 #### Set default options 
@@ -17,7 +16,8 @@
 # optmode=prod/dev/debug
 optmode=prod
-# Resolution if compiling LMDZ in regular mode without DYNAMICO
-# Use for example following "./compile_icolmdzor.sh -regular_lonlat 144x142x79"
-regular_latlon=no
+# Resolution of LMDZ in regular mode
+regular_latlon=yes
+resol_atm_3d=144x142x79
+
 # fcm_arch
 fcm_arch=default
@@ -30,7 +30,7 @@
 
 # Output text file for compilation of each component
-outfile=$submitdir/out_compile_icolmdzor
+outfile=$submitdir/out_compile_lmdzor
 rm -f $outfile; echo > $outfile
-echo; echo "Text output from compilation will be stored in file out_compile_icolmdzor"; echo 
+echo; echo "Text output from compilation will be stored in file out_compile_lmdzor"; echo 
 
 #### Read arguments 
@@ -41,5 +41,5 @@
 
 ########################################################################
 # Usage of the script compile_icolmdzor.sh
 #
 ########################################################################
@@ -49,16 +49,16 @@
 Options: -full, -regular_latlon, -debug, -dev, -prod(default)
 
-Example 1: Default compilation of DYNAMICO-LMDZ-ORCHIDEE with XIOS and IOIPSL
-./compile_icolmdzor.sh
+Example 1: Default compilation of LMDZ-ORCHIDEE with XIOS and IOIPSL
+./compile_lmdzor.sh
 
 Example 2: Compile in debug mode
-./compile_icolmdzor.sh -debug
+./compile_lmdzor.sh -debug
 
 Example 3: Default compilation with full recompilation of all components
-./compile_icolmdzor.sh -full
-
-Example 4: Compilation of LMDZ in regular lat-lon for dimension 144x142x79. 
-The dimension can be changed to any other 3d dimension. DYNAMICO is also compiled as default.
-./compile_icolmdzor.sh -regular_latlon 144x142x79
+./compile_lmdzor.sh -full
+
+Example 4: Compilation of LMDZ in regular lat-lon for other dimensions (default: 144x142x79) 
+The dimension can be changed to any other 3d dimension.
+./compile_lmdzor.sh -regular_latlon 96x95x79
 
 fin
@@ -154,4 +154,11 @@
 echo >> $outfile ; echo " NOW COMPILE IOIPSL"   >> $outfile 
 
+# Check if compilation with fcm is included in IOIPSL
+if [ ! -f makeioipsl_fcm ] ; then
+  echo "The file makeiopsl_fcm do not exist. Probably this is not the right version of IOIPSL."
+  echo "Version of IOIPSL with fcm compilation is needed to compile with this script. Stop now."
+  exit
+fi
+
 echo ./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag   >> $outfile 
      ./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag   >> $outfile 2>&1
@@ -195,55 +202,6 @@
 fi
 
-## 2.4 Compile lmdz
-cd $modipsl/modeles/LMDZ
-# Compile LMDZ as library to couple to DYNAMICO
-echo; echo "NOW COMPILE LMDZ FOR COUPLING TO DYNAMICO"
-echo >> $outfile ; echo " NOW COMPILE LMDZ FOR COUPLING TO DYNAMICO"   >> $outfile 
-
-echo ./makelmdz_fcm -p lmd -rrtm true -cosp true -$optmode -mem -parallel $parallel -libphy -v orchidee2.1 -io xios -arch $fcm_arch -j 8 $full_flag    >> $outfile 
-     ./makelmdz_fcm -p lmd -rrtm true -cosp true -$optmode -mem -parallel $parallel -libphy -v orchidee2.1 -io xios -arch $fcm_arch -j 8 $full_flag    >> $outfile 2>&1
-# Test if compiling finished
-if [[ $? != 0 ]] ; then
-    echo "THERE IS A PROBLEM IN LMDZ PHYSICS COMPILATION - STOP"
-    exit
-fi
-
-
-## 2.5 Compile DYNAMICO
-cd $modipsl/modeles/DYNAMICO
-echo; echo "NOW COMPILE DYNAMICO "
-echo >> $outfile ; echo " NOW COMPILE DYNAMICO"   >> $outfile 
-
-echo ./make_icosa -$optmode -parallel $parallel -external_ioipsl -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_flag    >> $outfile 
-     ./make_icosa -$optmode -parallel $parallel -external_ioipsl -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_flag    >> $outfile 2>&1
-# Test if compiling finished
-if [[ $? != 0 ]] ; then
-    echo "THERE IS A PROBLEM IN DYNAMICO COMPILATION - STOP"
-    exit
-fi
-
-## 2.6 Compile interface ICOSA_LMDZ
-cd $modipsl/modeles/ICOSA_LMDZ
-echo; echo "NOW COMPILE ICOSA_LMDZ "
-echo >> $outfile ; echo " NOW COMPILE ICOSA_LMDZ"   >> $outfile 
-
-echo ./make_icosa_lmdz -nodeps -p lmd -$optmode -parallel $parallel -with_orchidee -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_flag    >> $outfile 
-     ./make_icosa_lmdz -nodeps -p lmd -$optmode -parallel $parallel -with_orchidee -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_flag    >> $outfile 2>&1
-# Test if compiling finished
-if [[ $? != 0 ]] ; then
-    echo "THERE IS A PROBLEM IN ICOSA_LMDZ COMPILATION - STOP"
-    exit
-fi
-# Move executables to modipsl/bin
-if [ $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe ] ; then 
-    mv $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe $modipsl/bin/. 
-else
-    echo "THERE IS A PROBLEM IN ICOSA_LMDZ COMPILATION EXECUTABLE MISSING - STOP"
-    exit
-fi
-
-
-
-## 2.7 Compile LMDZ for regular latlon configuration
+
+## 2.4 Compile LMDZ for regular latlon configuration
 if [ $regular_latlon = yes ] ; then
 
@@ -41,5 +41,5 @@
 
 ########################################################################
-# Usage of the script compile_icolmdzor.sh
+# Usage of the script compile_lmdzor.sh
 #
 ########################################################################
